@@ -41,13 +41,15 @@ class Client:
         version: str = None,
         num_workers: int = 8,
         request_dict: dict = {},
-        check_api_key: bool = True
+        check_api_key: bool = True,
+        headers: dict = {}
     ) -> None:
         self.api_key = api_key
         self.api_url = clueai.MODELFUN_API_URL
         self.text_2_image_api_url = clueai.TEXT_TO_IMAGE_URL
         self.num_workers = num_workers
         self.request_dict = request_dict
+        self.headers = headers
         if version is None:
             self.modelfun_version = clueai.MODELFUN_VERSION
         else:
@@ -105,16 +107,16 @@ class Client:
         if style:
             url = f"{self.text_2_image_api_url}使用{style}风格画{prompt}"
         
-        headers = {
+        tmp_headers = {
             'Api-Key': 'BEARER {}'.format(self.api_key),
             'Content-Type': 'application/json',
             'Request-Source': 'python-sdk',
             'Model-name': model_name
         }
         if self.modelfun_version != '':
-            headers['clueai-Version'] = self.modelfun_version
-
-        response = requests.get(url, headers=headers)
+            tmp_headers['clueai-Version'] = self.modelfun_version
+        self.headers.update(tmp_headers)
+        response = requests.get(url, headers=self.headers)
         img = response.content
         with open(out_file_path, "wb") as f:
             f.write(img)
@@ -264,22 +266,23 @@ class Client:
         return res
 
     def __request(self, json_body, endpoint, model_name) -> Any:
-        headers = {
+        tmp_headers = {
             'Api-Key': 'BEARER {}'.format(self.api_key),
             'Content-Type': 'application/json',
             'Request-Source': 'python-sdk',
             'Model-name': model_name
         }
         if self.modelfun_version != '':
-            headers['clueai-Version'] = self.modelfun_version
+            tmp_headers['clueai-Version'] = self.modelfun_version
+        self.headers.update(tmp_headers)
 
         url = urljoin(self.api_url, endpoint)
         #print(json_body)
         if use_xhr_client:
-            response = self.__pyfetch(url, headers, json_body)
+            response = self.__pyfetch(url, self.headers, json_body)
             return response
         else:
-            response = requests.post(url, json=json.loads(json_body), headers=headers)
+            response = requests.post(url, json=json.loads(json_body), headers=self.headers)
             try:
                 res = json.loads(response.text)
             except Exception:
